<img src="https://github.com/MrEchoFi/GreeDoS_V2/blob/master/thumbnail-b9f492e1-4655-4c87-8035-e8d9a0efea7a.jpeg?raw=true"  alt="logo" width="801" height="auto" />
<div align="center">


  <img src="https://github.com/MrEchoFi/MrEchoFi/raw/4274f537dec313ac7dde4403fe0fae24259beade/Mr.EchoFi-New-Logo-with-ASCII.jpg" alt="logo" width="245" height="auto" />
  <h1>GreeDoS_V2</h1>
   
  <p>
   ~ A Cybersecurity Red Team tool based on DDoS ~
  </p>


  📫 How to reach me  **[Website](https://echo-fi-portfolio-node-js.vercel.app/)** ,  **http://mrechofi.github.io/Tanjib_portfolio_website/** & **tanjibisham777@gmail.com & tanjibisham888@gmail.com** | **https://369emon.github.io/Emon-s_portfolio/**.
  </div>
## See the video & listen,
  <div align="center">

  https://github.com/user-attachments/assets/370cb1ce-ab07-418f-af4f-3c210e063436

</div>
   
   <pre> in this video See the video i'm using fake or dummy IP to show you that my tool is working perfectly!
    And yeah i'm using fake IP cause if i use someone real IP then it will be very harmful & unauthorized activity.
    for your better understanding i choose HTTP flood and then multi-vector attack to show you that how my tool is working and you can try other attacks or full attacks 
    via real IP but this have to contains authorization and proper lab environment for test my tool. By the way, by using fake IP my HTTP flood & multi-vector attack 
    request remains zero, cause this IP doesn't exists or you can say this is not active. i know you are all know about this IP concept but i have just told you that for 
    better understanding cause i testing my tool by a dummy IP in this video. And when you will use real origin IP then this tool can be a great nightmare for targeted 
    servers cause this tool contains versatile attacks and vectors!
    This tool can damage easily 5 to 6 layers servers; but make sure you are using real-origin IP.
    And the one more thing is,if you really want to disrupt the black hat hackers sites or data center then make sure that you will use bot net for running GreeDoS 
    perfectly in real cyber world.
    i hope you have understand perfectly.
    Best of luck and good bye for now.... 
   </pre>


# Installation Process via 'git' :
    git clone <paste_the_github_link>

    cd GreeDoS_V2

    // install external libraries, 

    pip install requests scapy rich

    or,

    pip install -r requirements.txt

    // If you want to ensure everything is up-to-date, you can use:

     pip install --upgrade requests scapy rich

    // then run the tool,
   
    python3 GreeDoS_ii.py

Note: Install Npcap externally.

# Install Tcpreplay for high-speed packet replay:
   sudo apt install tcpreplay
   

# Recommendations:
  <pre> 
        - you can run this tool in Ubuntu, kali linux, WSL, Debian & Arch, Parrot OS.
        - Use good level of router & ethernet cable.
        - If u want to run this tool aggressively for testing or lab based attacks with more time & thread then use high CPU, GPU and RAM based device.
  </pre>
